@@ -14,7 +14,7 @@ use constant SKIP      => 2;
 #inherits Apache::Session
 #link Lemonldap::NG::Common::Apache::Session::SOAP protected globalStorage
 
-our $VERSION = '1.9.2';
+our $VERSION = '1.9.4';
 our ( %EXPORT_TAGS, @EXPORT_OK, @EXPORT );
 
 our $tsv = {};    # Hash ref containing thread-shared values, filled
@@ -208,6 +208,19 @@ sub retrieveSession {
         Lemonldap::NG::Handler::Main::Logger->lmLog( "Get session $id",
             'debug' );
 
+        # Verify that session is valid
+        if (
+            $now - $datas->{_utime} > $tsv->{timeout}
+            or (    $tsv->{timeoutActivity}
+                and $datas->{_lastSeen}
+                and $now - $datas->{_lastSeen} > $tsv->{timeoutActivity} )
+          )
+        {
+            Lemonldap::NG::Handler::Main::Logger->lmLog( "Session expired",
+                'info' );
+            return 0;
+        }
+
         # Update the session to notify activity, if necessary
         if ( $tsv->{timeoutActivity} and ( $now - $datas->{_lastSeen} > 60 ) ) {
             $session->update( { '_lastSeen' => $now } );
