@@ -18,7 +18,7 @@ has error => ( is => 'rw' );
 
 our $VERSION = '1.9.1';
 
-use Lemonldap::NG::Handler::Main '$datas';
+use Lemonldap::NG::Handler::Main '$datas', '$tsv';
 use Lemonldap::NG::Handler::API ':functions';
 
 ## @imethod protected build_jail()
@@ -67,7 +67,8 @@ sub build_jail {
     $self->jail->share_from( 'Lemonldap::NG::Common::Safelib',
         $Lemonldap::NG::Common::Safelib::functions );
 
-    $self->jail->share_from( 'Lemonldap::NG::Handler::Main', ['$datas'] );
+    $self->jail->share_from( 'Lemonldap::NG::Handler::Main',
+        [ '$tsv', '$datas' ] );
     $self->jail->share_from(
         'Lemonldap::NG::Handler::API',
         [
@@ -75,12 +76,17 @@ sub build_jail {
               &unparsed_uri &args &method &header_in   )
         ]
     );
-    $self->jail->share_from( __PACKAGE__, [@t] );
+    $self->jail->share_from( __PACKAGE__, [ @t, '&encrypt' ] );
     $self->jail->share_from( 'MIME::Base64', ['&encode_base64'] );
 
     return $self->jail;
 }
 
+# Import crypto methods for jail
+sub encrypt {
+    return $tsv->{cipher}->encrypt(@_);
+}
+
 ## @method reval
 # Fake reval method if useSafeJail is off
 sub reval {
